%-----------------------------------------------------------------------
% Job saved on 28-Apr-2015 22:57:10 by cfg_util (rev $Rev: 6134 $)
% spm SPM - SPM12 (6225)
% cfg_basicio BasicIO - Unknown
%-----------------------------------------------------------------------
matlabbatch{1}.spm.spatial.normalise.est.subj.vol = {'%filename%'};
matlabbatch{1}.spm.spatial.normalise.est.eoptions.biasreg = %biasreg%;
matlabbatch{1}.spm.spatial.normalise.est.eoptions.biasfwhm = %biasfwhm%;
matlabbatch{1}.spm.spatial.normalise.est.eoptions.tpm = {'%spmdir%/tpm/TPM.nii'};
matlabbatch{1}.spm.spatial.normalise.est.eoptions.affreg = %affreg%';
matlabbatch{1}.spm.spatial.normalise.est.eoptions.reg = %reg%;
matlabbatch{1}.spm.spatial.normalise.est.eoptions.fwhm = %fwhm%;
matlabbatch{1}.spm.spatial.normalise.est.eoptions.samp = %samp%;
